@@ -52,6 +52,12 @@
 #define RSTTO_MAX_SCALE 4.0
 #endif
 
+enum
+{
+    PROP_0,
+    PROP_SHOW_CLOCK
+};
+
 typedef enum
 {
     RSTTO_IMAGE_VIEWER_MOTION_STATE_NORMAL = 0,
@@ -87,6 +93,10 @@ struct _RsttoImageViewerPriv
         gdouble height;
     } rendering;
 
+    struct
+    {
+        gboolean show_clock;
+    } props;
 
     GtkMenu                     *menu;
     gboolean                     revert_zoom_direction;
@@ -97,6 +107,8 @@ struct _RsttoImageViewerPriv
     GdkPixbufAnimationIter *iter;
     gint                    animation_timeout_id;
 
+    gint                    refresh_timeout_id;
+
     gdouble                 scale;
     gboolean                auto_scale;
 
@@ -173,6 +185,19 @@ rstto_image_viewer_expose(GtkWidget *, GdkEventExpose *);
 static void
 rstto_image_viewer_paint (GtkWidget *widget, cairo_t *);
 
+static void
+rstto_image_viewer_set_property (
+        GObject      *object,
+        guint         property_id,
+        const GValue *value,
+        GParamSpec   *pspec);
+static void
+rstto_image_viewer_get_property (
+        GObject    *object,
+        guint       property_id,
+        GValue     *value,
+        GParamSpec *pspec);
+
 static void
 rstto_image_viewer_set_motion_state (RsttoImageViewer *viewer, RsttoImageViewerMotionState state);
 
@@ -351,6 +376,7 @@ rstto_image_viewer_init ( GObject *object )
 static void
 rstto_image_viewer_class_init(RsttoImageViewerClass *viewer_class)
 {
+    GParamSpec *pspec;
     GtkWidgetClass *widget_class;
     GtkObjectClass *object_class;
 
@@ -374,6 +400,10 @@ rstto_image_viewer_class_init(RsttoImageViewerClass *viewer_class)
 
     object_class->destroy = rstto_image_viewer_destroy;
 
+    G_OBJECT_CLASS(object_class)->set_property = rstto_image_viewer_set_property;
+    G_OBJECT_CLASS(object_class)->get_property = rstto_image_viewer_get_property;
+
+
     widget_class->set_scroll_adjustments_signal =
                   g_signal_new ("set_scroll_adjustments",
                                 G_TYPE_FROM_CLASS (object_class),
@@ -407,6 +437,17 @@ rstto_image_viewer_class_init(RsttoImageViewerClass *viewer_class)
             g_cclosure_marshal_VOID__POINTER,
             G_TYPE_NONE, 1,
             G_TYPE_POINTER);
+
+    pspec = g_param_spec_boolean (
+            "show-clock",
+            "",
+            "",
+            FALSE,
+            G_PARAM_READWRITE);
+    g_object_class_install_property (
+            G_OBJECT_CLASS(object_class),
+            PROP_SHOW_CLOCK,
+            pspec);
 }
 
 /**
@@ -962,6 +1003,93 @@ correct_adjustments ( RsttoImageViewer *viewer )
     g_object_thaw_notify(G_OBJECT(viewer->vadjustment));
 }
 
+static void
+paint_clock (
+        GtkWidget *widget,
+        cairo_t *ctx )
+{
+    //RsttoImageViewer *viewer = RSTTO_IMAGE_VIEWER (widget);
+    gdouble width = 60;
+    gdouble height = 60;
+    gdouble offset = height*0.15;
+    gint i = 0;
+    time_t t = time(NULL);
+    struct tm *lt = localtime(&t);
+
+    gdouble hour_angle = (gdouble)(M_PI*2)/12*((gdouble)(lt->tm_hour%12+6)+((M_PI*2)/720.0*(gdouble)lt->tm_min));
+
+    cairo_save (ctx);
+
+    cairo_translate (
+        ctx,
+        widget->allocation.width-offset-width,
+        widget->allocation.height-offset-height);
+
+    cairo_set_source_rgba (ctx, 0.0, 0.0, 0.0, 0.4);
+    cairo_save(ctx);
+    cairo_translate (
+        ctx,
+        width/2,
+        height/2);
+    cairo_arc (
+        ctx,
+        00, 00,
+        width/2,
+        0,
+        2*M_PI );
+    cairo_fill (ctx);
+
+    cairo_set_source_rgba (ctx, 1.0, 1.0, 1.0, 0.8);
+
+    cairo_save(ctx);
+    for (i = 0; i < 12; ++i)
+    {
+        cairo_rotate (
+            ctx,
+            30*(M_PI/180));
+        cairo_arc (
+            ctx,
+            00, -1*((width/2)-5),
+            3,
+            0,
+            2*M_PI );
+        cairo_fill (ctx);
+    }
+    cairo_restore (ctx);
+
+/***/
+    cairo_save (ctx);
+    cairo_set_line_width (ctx, 5.0);
+    cairo_set_line_cap (ctx, CAIRO_LINE_CAP_ROUND);
+    cairo_rotate (
+        ctx,
+        hour_angle);
+    cairo_move_to (ctx, 0, 0);
+    cairo_line_to (
+        ctx,
+        0,
+        height*0.2);
+    cairo_stroke (
+        ctx);
+    cairo_restore (ctx);
+/***/
+    cairo_set_line_width (ctx, 5.0);
+    cairo_set_line_cap (ctx, CAIRO_LINE_CAP_ROUND);
+    cairo_rotate (
+        ctx,
+        (M_PI*2)/60*(lt->tm_min%60+30));
+    cairo_move_to (ctx, 0, 0);
+    cairo_line_to (
+        ctx,
+        0,
+        height*0.3);
+    cairo_stroke (
+        ctx);
+
+    cairo_restore (ctx);
+    cairo_restore (ctx);
+}
+
 static void
 paint_image (
         GtkWidget *widget,
@@ -1339,6 +1467,13 @@ rstto_image_viewer_paint (GtkWidget *widget, cairo_t *ctx)
             paint_background_icon (widget, ctx);        
 
             cairo_restore (ctx);
+
+            if (viewer->priv->props.show_clock)
+            {
+                cairo_save (ctx);
+                paint_clock (widget, ctx);        
+                cairo_restore (ctx);
+            }
         }
         else
         {
@@ -1352,6 +1487,13 @@ rstto_image_viewer_paint (GtkWidget *widget, cairo_t *ctx)
                 paint_selection_box (widget, ctx);        
                 cairo_restore (ctx);
             }
+
+            if (viewer->priv->props.show_clock)
+            {
+                cairo_save (ctx);
+                paint_clock (widget, ctx);        
+                cairo_restore (ctx);
+            }
         }
     }
 }
@@ -2642,3 +2784,74 @@ rstto_image_viewer_get_error ( RsttoImageViewer *viewer )
     }
     return NULL;
 }
+
+static void
+rstto_image_viewer_set_property (
+        GObject      *object,
+        guint         property_id,
+        const GValue *value,
+        GParamSpec   *pspec)
+{
+    RsttoImageViewer *viewer = RSTTO_IMAGE_VIEWER (object);
+
+    switch (property_id)
+    {
+        case PROP_SHOW_CLOCK:
+            viewer->priv->props.show_clock = g_value_get_boolean (value);
+            break;
+    }
+}
+
+static void
+rstto_image_viewer_get_property (
+        GObject    *object,
+        guint       property_id,
+        GValue     *value,
+        GParamSpec *pspec)
+{
+    RsttoImageViewer *viewer = RSTTO_IMAGE_VIEWER (object);
+
+    switch (property_id)
+    {
+        case PROP_SHOW_CLOCK:
+            g_value_set_boolean (value, viewer->priv->props.show_clock);
+            break;
+    }
+}
+
+static gboolean
+cb_rstto_image_viewer_refresh (RsttoImageViewer *viewer)
+{
+    GtkWidget *widget = GTK_WIDGET (viewer);
+
+    gdk_window_invalidate_rect (
+            widget->window,
+            NULL,
+            FALSE);
+
+    return TRUE;
+}
+
+void
+rstto_image_viewer_set_show_clock (
+        RsttoImageViewer *viewer,
+        gboolean value)
+{
+    viewer->priv->props.show_clock = value;
+    if ( viewer->priv->props.show_clock )
+    {
+        viewer->priv->refresh_timeout_id = g_timeout_add(
+                15000,
+                (GSourceFunc)cb_rstto_image_viewer_refresh, viewer);
+    }
+    else
+    {
+        if (viewer->priv->refresh_timeout_id)
+        {
+            g_source_remove (
+                    viewer->priv->refresh_timeout_id );
+            viewer->priv->refresh_timeout_id = 0;
+        }
+    }
+}
+
