@@ -20,6 +20,7 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <xfconf/xfconf.h>
 #include <libxfce4util/libxfce4util.h>
 
@@ -58,6 +59,7 @@ enum
     PROP_NAVBAR_POSITION,
     PROP_SHOW_THUMBNAILBAR,
     PROP_SHOW_STATUSBAR,
+    PROP_SHOW_CLOCK,
     PROP_HIDE_THUMBNAILBAR_FULLSCREEN,
     PROP_WINDOW_WIDTH,
     PROP_WINDOW_HEIGHT,
@@ -71,7 +73,6 @@ enum
     PROP_REVERT_ZOOM_DIRECTION,
     PROP_USE_THUNAR_PROPERTIES,
     PROP_MAXIMIZE_ON_STARTUP,
-    PROP_MERGE_TOOLBARS,
     PROP_ERROR_MISSING_THUMBNAILER,
     PROP_SORT_TYPE,
     PROP_THUMBNAIL_SIZE,
@@ -110,6 +111,7 @@ struct _RsttoSettingsPriv
     gboolean  show_toolbar;
     gboolean  show_thumbnailbar;
     gboolean  show_statusbar;
+    gboolean  show_clock;
     gboolean  hide_thumbnailbar_fullscreen;
     gchar    *navigationbar_position;
     gboolean  revert_zoom_direction;
@@ -124,7 +126,6 @@ struct _RsttoSettingsPriv
     gchar    *desktop_type;
     gboolean  use_thunar_properties;
     gboolean  maximize_on_startup;
-    gboolean  merge_toolbars;
     RsttoThumbnailSize thumbnail_size;
 
     RsttoSortType sort_type;
@@ -152,6 +153,21 @@ rstto_settings_init (GObject *object)
         g_free (accelmap_path);
         accelmap_path = NULL;
     }
+    else
+    {
+        /* If the accels.scm file is missing, we are probably
+         * dealing with a first-boot. Add default accelerators.
+         */
+        gtk_accel_map_change_entry ("<Window>/fullscreen", GDK_F, 0, FALSE);
+        gtk_accel_map_change_entry ("<Window>/unfullscreen", GDK_Escape, 0, FALSE);
+        gtk_accel_map_change_entry ("<Window>/next-image", GDK_Page_Down, 0, FALSE);
+        gtk_accel_map_change_entry ("<Window>/previous-image", GDK_Page_Up, 0, FALSE);
+        gtk_accel_map_change_entry ("<Window>/quit", GDK_q, 0, FALSE);
+
+        gtk_accel_map_change_entry ("<Window>/delete", GDK_Delete, GDK_SHIFT_MASK, FALSE);
+
+        gtk_accel_map_change_entry ("<Actions>/RsttoWindow/play", GDK_F5, 0, FALSE);
+    }
     
     settings->priv->slideshow_timeout = 5;
     settings->priv->bgcolor = g_new0 (GdkColor, 1);
@@ -270,6 +286,13 @@ rstto_settings_init (GObject *object)
             settings,
             "revert-zoom-direction");
 
+    xfconf_g_property_bind (
+            settings->priv->channel,
+            "/window/show-clock",
+            G_TYPE_BOOLEAN,
+            settings,
+            "show-clock");
+
     xfconf_g_property_bind (
             settings->priv->channel,
             "/image/wrap",
@@ -291,13 +314,6 @@ rstto_settings_init (GObject *object)
             settings,
             "maximize-on-startup");
 
-    xfconf_g_property_bind (
-            settings->priv->channel,
-            "/window/merge-toolbars",
-            G_TYPE_BOOLEAN,
-            settings,
-            "merge-toolbars");
-
     xfconf_g_property_bind (
             settings->priv->channel,
             "/errors/missing-thumbnailer",
@@ -389,6 +405,17 @@ rstto_settings_class_init (GObjectClass *object_class)
             PROP_SHOW_STATUSBAR,
             pspec);
 
+    pspec = g_param_spec_boolean (
+            "show-clock",
+            "",
+            "",
+            TRUE,
+            G_PARAM_READWRITE);
+    g_object_class_install_property (
+            object_class,
+            PROP_SHOW_CLOCK,
+            pspec);
+
     pspec = g_param_spec_boolean (
             "hide-thumbnailbar-fullscreen",
             "",
@@ -523,17 +550,6 @@ rstto_settings_class_init (GObjectClass *object_class)
             PROP_MAXIMIZE_ON_STARTUP,
             pspec);
 
-    pspec = g_param_spec_boolean (
-            "merge-toolbars",
-            "",
-            "",
-            TRUE,
-            G_PARAM_READWRITE);
-    g_object_class_install_property (
-            object_class,
-            PROP_MERGE_TOOLBARS,
-            pspec);
-
     pspec = g_param_spec_boolean (
             "show-error-missing-thumbnailer",
             "",
@@ -661,6 +677,9 @@ rstto_settings_set_property    (GObject      *object,
         case PROP_SHOW_STATUSBAR:
             settings->priv->show_statusbar = g_value_get_boolean (value);
             break;
+        case PROP_SHOW_CLOCK:
+            settings->priv->show_clock = g_value_get_boolean (value);
+            break;
         case PROP_HIDE_THUMBNAILBAR_FULLSCREEN:
             settings->priv->hide_thumbnailbar_fullscreen = g_value_get_boolean (value);
             break;
@@ -723,9 +742,6 @@ rstto_settings_set_property    (GObject      *object,
         case PROP_MAXIMIZE_ON_STARTUP:
             settings->priv->maximize_on_startup = g_value_get_boolean (value);
             break;
-        case PROP_MERGE_TOOLBARS:
-            settings->priv->merge_toolbars = g_value_get_boolean (value);
-            break;
         case PROP_ERROR_MISSING_THUMBNAILER:
             settings->priv->errors.missing_thumbnailer = g_value_get_boolean (value);
             break;
@@ -760,6 +776,9 @@ rstto_settings_get_property    (GObject    *object,
         case PROP_SHOW_STATUSBAR:
             g_value_set_boolean (value, settings->priv->show_statusbar);
             break;
+        case PROP_SHOW_CLOCK:
+            g_value_set_boolean (value, settings->priv->show_clock);
+            break;
         case PROP_HIDE_THUMBNAILBAR_FULLSCREEN:
             g_value_set_boolean (value, settings->priv->hide_thumbnailbar_fullscreen);
             break;
@@ -802,9 +821,6 @@ rstto_settings_get_property    (GObject    *object,
         case PROP_MAXIMIZE_ON_STARTUP:
             g_value_set_boolean (value, settings->priv->maximize_on_startup);
             break;
-        case PROP_MERGE_TOOLBARS:
-            g_value_set_boolean (value, settings->priv->merge_toolbars);
-            break;
         case PROP_ERROR_MISSING_THUMBNAILER:
             g_value_set_boolean (
                     value,
