@@ -47,7 +47,34 @@ typedef enum {
     SORT_TYPE_COUNT,
 } RsttoSortType;
 
-gboolean
-rstto_launch_help (void);
+
+#define THUMBNAIL_SIZE_VERY_SMALL_SIZE   24
+#define THUMBNAIL_SIZE_SMALLER_SIZE      32
+#define THUMBNAIL_SIZE_SMALL_SIZE        48
+#define THUMBNAIL_SIZE_NORMAL_SIZE       64
+#define THUMBNAIL_SIZE_LARGE_SIZE        96
+#define THUMBNAIL_SIZE_LARGER_SIZE      128
+#define THUMBNAIL_SIZE_VERY_LARGE_SIZE  256
+
+typedef enum {
+    THUMBNAIL_SIZE_VERY_SMALL = 0,
+    THUMBNAIL_SIZE_SMALLER,
+    THUMBNAIL_SIZE_SMALL,
+    THUMBNAIL_SIZE_NORMAL,
+    THUMBNAIL_SIZE_LARGE,
+    THUMBNAIL_SIZE_LARGER,
+    THUMBNAIL_SIZE_VERY_LARGE,
+    THUMBNAIL_SIZE_COUNT,
+} RsttoThumbnailSize;
+
+#define THUMBNAIL_SIZE_VERY_SMALL_SIZE   24
+#define THUMBNAIL_SIZE_SMALLER_SIZE      32
+#define THUMBNAIL_SIZE_SMALL_SIZE        48
+#define THUMBNAIL_SIZE_NORMAL_SIZE       64
+#define THUMBNAIL_SIZE_LARGE_SIZE        96
+#define THUMBNAIL_SIZE_LARGER_SIZE      128
+#define THUMBNAIL_SIZE_VERY_LARGE_SIZE  256
+
+G_END_DECLS
 
 #endif /* __RSTTO_UTIL_H__ */
